
sncosmo.ABMagSystem
===================

.. currentmodule:: sncosmo

.. autoclass:: ABMagSystem
   :show-inheritance:

   
   
   .. rubric:: Attributes

   .. autosummary::
   
         name
         refmags
   
   


   
   
   .. rubric:: Methods Summary

   .. autosummary::
   
      ~ABMagSystem.band_flux_to_mag
      ~ABMagSystem.band_mag_to_flux
      ~ABMagSystem.zpbandflux
   
   


   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: band_flux_to_mag
   .. automethod:: band_mag_to_flux
   .. automethod:: zpbandflux

   
   